==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-taskbar/translations/taskbar_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>Võta %1 kasutusele</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="677"/>
        <source>Application</source>
        <translation>Rakendus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>To &amp;Desktop</source>
        <translation>Saada töö&amp;lauale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="713"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Kõikidele töölaudadele</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="721"/>
        <source>Desktop &amp;%1</source>
        <translation>Töölauale &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="728"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Praegusele töölauale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="737"/>
        <source>Move To &amp;Next Monitor</source>
        <translation>Tõsta &amp;järgmisele ekraanile</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="740"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Tõsta &amp;eelmisele ekraanile</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="744"/>
        <source>&amp;Move</source>
        <translation>&amp;Tõsta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="747"/>
        <source>Resi&amp;ze</source>
        <translation>Muuda &amp;suurust</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>Ma&amp;ximize</source>
        <translation>Suu&amp;renda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="761"/>
        <source>Maximize vertically</source>
        <translation>Suurenda püstloodis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="766"/>
        <source>Maximize horizontally</source>
        <translation>Suurenda rõhtloodis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="772"/>
        <source>&amp;Restore</source>
        <translation>&amp;Taasta suurus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="776"/>
        <source>Mi&amp;nimize</source>
        <translation>Vä&amp;henda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="782"/>
        <source>Roll down</source>
        <translation>Rulli lahti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="788"/>
        <source>Roll up</source>
        <translation>Rulli kokku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="796"/>
        <source>&amp;Layer</source>
        <translation>&amp;Kihid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>Always on &amp;top</source>
        <translation>Alati kõige &amp;peal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="804"/>
        <source>&amp;Normal</source>
        <translation>&amp;Näita tavakihil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="810"/>
        <source>Always on &amp;bottom</source>
        <translation>Alati kõige &amp;all</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="818"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulge</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="81"/>
        <source>Group</source>
        <translation>Akende grupp</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="83"/>
        <source>Close group</source>
        <translation>Sulge akende grupp</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Tegumihalduri seadistused</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Üldist</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Näita töölaua aknaid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Näita vaid aknaid, mis töötavad antud &amp;paneeli ekraanil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Näita vaid vähendatud aknaid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Suurenda vähendatud aknad vaid sellel töölaual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Sulgemiseks kasuta hiire keskmist nuppu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Hiireratta kerimisel lappa aknaid läbi</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Akende &amp;rühmitamine</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Hiirekursori alla näita teabeakent</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Välimus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Nuppude stiil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Nuppude suurim laius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Hiire ratas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Hiireratta läve vahemik</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Aseta sama tüüpi nupud kõrvuti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Nuppude suurim kõrgus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Kui paneel asub püstloodis, siis pööra nupud &amp;automaatselt</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Kui võimalik, siis kasuta ikoone AknaKlassi alusel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Ikoon ja tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Ei ole kasutusel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Akna suurendamiseks rulli üles, vähendamiseks rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Akna vähendamiseks rulli üles, suurendamiseks rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Akna tõstmiseks järgmisele töölauale rulli üles, tõstmiseks eelmisele töölauale rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Akna tõstmiseks eelmisele töölauale rulli üles, tõstmiseks järgmisele töölauale rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Praegune töölaud</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-taskbar/translations/taskbar_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="636"/>
        <source>Activate task %1</source>
        <translation>Võta %1 kasutusele</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="546"/>
        <source>Application</source>
        <translation>Rakendus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="580"/>
        <source>To &amp;Desktop</source>
        <translation>Saada töö&amp;lauale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="583"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Kõikidele töölaudadele</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="593"/>
        <source>Desktop &amp;%1</source>
        <translation>Töölauale &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="603"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Praegusele töölauale</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Tõsta &amp;järgmisele ekraanile</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="618"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Tõsta &amp;eelmisele ekraanile</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="624"/>
        <source>&amp;Move</source>
        <translation>&amp;Tõsta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="629"/>
        <source>Resi&amp;ze</source>
        <translation>Muuda &amp;suurust</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Ma&amp;ximize</source>
        <translation>Suu&amp;renda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="647"/>
        <source>Maximize vertically</source>
        <translation>Suurenda püstloodis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="654"/>
        <source>Maximize horizontally</source>
        <translation>Suurenda rõhtloodis</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="662"/>
        <source>&amp;Restore</source>
        <translation>&amp;Taasta suurus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="670"/>
        <source>Mi&amp;nimize</source>
        <translation>Vä&amp;henda</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="678"/>
        <source>Roll down</source>
        <translation>Rulli lahti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>Roll up</source>
        <translation>Rulli kokku</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Layer</source>
        <translation>&amp;Kihid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="700"/>
        <source>Always on &amp;top</source>
        <translation>Alati kõige &amp;peal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="705"/>
        <source>&amp;Normal</source>
        <translation>&amp;Näita tavakihil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>Always on &amp;bottom</source>
        <translation>Alati kõige &amp;all</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="717"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulge</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Group</source>
        <translation>Akende grupp</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="86"/>
        <source>Close group</source>
        <translation>Sulge akende grupp</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Tegumihalduri seadistused</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Üldist</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Näita töölaua aknaid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Näita vaid aknaid, mis töötavad antud &amp;paneeli ekraanil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Näita vaid vähendatud aknaid</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Suurenda vähendatud aknad vaid sellel töölaual</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Sulgemiseks kasuta hiire keskmist nuppu</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Hiireratta kerimisel lappa aknaid läbi</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Akende &amp;rühmitamine</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Hiirekursori alla näita teabeakent</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Välimus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Nuppude stiil</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Nuppude suurim laius</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Hiire ratas</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Hiireratta läve vahemik</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Aseta sama tüüpi nupud kõrvuti</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Nuppude suurim kõrgus</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Kui paneel asub püstloodis, siis pööra nupud &amp;automaatselt</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Kui võimalik, siis kasuta ikoone AknaKlassi alusel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Ikoon ja tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Ainult ikoon</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Ainult tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Disabled</source>
        <translation>Ei ole kasutusel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Akna suurendamiseks rulli üles, vähendamiseks rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Akna vähendamiseks rulli üles, suurendamiseks rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="54"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Akna tõstmiseks järgmisele töölauale rulli üles, tõstmiseks eelmisele töölauale rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Akna tõstmiseks eelmisele töölauale rulli üles, tõstmiseks järgmisele töölauale rulli alla</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="60"/>
        <source>Current</source>
        <translation>Praegune töölaud</translation>
    </message>
</context>
</TS>
